@@ -158,7 +158,7 @@ class TextEdit : public QTextEdit
 
 	private:
 		QVector<QRect> coordsToRects(QRect coords) {
-			// this methods calcultate the viewport rectangles that cover a (multi-line) word or error
+			// this methods calculate the viewport rectangles that cover a (multi-line) word or error
             // after switching the tokenizer to use the QTextDocument we might optimize this methods
 			int startRow, startCol, endRow, endCol;
 			coords.getCoords(&startRow, &startCol, &endRow, &endCol);
@@ -200,7 +200,7 @@ class Editor : public QFrame
 	Q_OBJECT
 
 	public:
-		Editor(QWidget *parent = nullptr);
+		explicit Editor(QWidget *parent = nullptr);
 		~Editor();
 
 		QTextEdit* view() const { return editor; }
